Documentation
¶
Overview ¶
Package cmdstream constructs all stream verbs with isolated operation bindings.
Package cmdstream constructs all stream verbs with isolated operation bindings.
Package cmdstream constructs all stream verbs with isolated operation bindings.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
Types ¶
type Dependencies ¶
type Dependencies struct {
Start func(context.Context, streamrun.Creation, streams.StartOptions) (streams.StartResult, error)
Join func(context.Context, streamrun.Creation, streams.JoinOptions) (streams.StartResult, error)
List func(context.Context, string) ([]streams.Stream, []streams.Unreadable, error)
Status func(context.Context, string, string) (streams.Status, error)
End func(context.Context, string, streams.EndOptions) (streams.EndResult, error)
Delete func(string, string) error
Sync func(context.Context, streamrun.SyncRequest) ([]streamsync.Result, error)
RegisteredSession func() bool
PrepareWorkLog func(string, string, worktrees.WorkLogOptions) (worktrees.WorkLogOptions, error)
}
Dependencies are the concrete operations consumed by the six stream verbs.
Click to show internal directories.
Click to hide internal directories.